==> libgtk-java-2.5.3.tar.bz2: libgtk-java-2.5.3/src/java/org/gnu/gtk/TreeSortableHelper.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import java.util.Hashtable;
import org.gnu.glib.Handle;
import org.gnu.glib.Type;

/**
 * Internal helper class for classes that implement the {@link TreeSortable} 
 * interface. Applications normally shouldn't use this class.
 */
public class TreeSortableHelper {

    private static Hashtable sortMethods = null;

    /**
     * Set the column in the list to sort on.
     */
    public static void setSortColumn( TreeSortable sortable, 
                                      DataColumn column, SortType order ) {
        gtk_tree_sortable_set_sort_column_id( sortable.getHandle(), 
                                              column.getColumn(), 
                                              order.getValue() );
    }

    /**
     * Get a DataColumn object representing the currently sorted column.  This
     * is not the same DataColumn used to create the store.  It is only of type
     * DataColumn (not DataColumnString, etc).  It can be compared with another
     * DataColumn object using the <tt>{@link DataColumn#equals}</tt> method.
     *
     * @return A DataColumn object representing the currently sorted column or
     * <tt>null</tt> if there is no column currently sorted.
     */
    public static DataColumn getSortColumn( TreeSortable sortable ) {
        int colid = gtk_tree_sortable_get_sort_column_id( sortable.getHandle() );
        if ( colid < 0 ) {
            return null;
        } else {
            DataColumn ret = new DataColumnInt();
            ret.setColumn( colid );
            return ret;
        }
    }

    /**
     * Get the current sorting order of the store.
     *
     * @return A SortType object defining the current sorting order of the 
     * store or <tt>null</tt> if there is no current sort order.
     */
    public static SortType getSortOrder( TreeSortable sortable ) {
        int stype = gtk_tree_sortable_get_sort_column_order( sortable.getHandle() );
        if ( stype == -1 ) {
            return null;
        } else {
            return SortType.intern( stype );
        }
    }

    /**
     * Set the class used to sort the list according to the values stored
     * in the given DataColumn.
     * <p>
     * "handleCompareFunc" is part of the TreeSortable interface.
     */
    public static void setSortMethod( TreeSortable sortable, 
                                      TreeIterComparison method, 
                                      DataColumn column ) {
        // sortMethods is a hashtable of hashtables.  that is, each key
        // (TreeSortable objects) refers to hashtable that contains
        // TreeIterComparison objects keyed to their column number.
        if ( sortMethods == null ) {
            sortMethods = new Hashtable();
        }
        Hashtable sortablehash = (Hashtable)sortMethods.get( sortable );
        if ( sortablehash == null ) {
            sortablehash = new Hashtable();
            sortMethods.put( sortable, sortablehash );
        }
        sortablehash.put( new Integer( column.getColumn() ), method );
        gtk_tree_sortable_set_sort_func( sortable.getHandle(), sortable,
                                         "handleCompareFunc", 
                                         column.getColumn() );
    }

    /**
     * Get the TreeIterComparison object stored for this column.  For internal
     * use only.
     */
    public static TreeIterComparison getMethod( TreeSortable sortable,
                                                int column ) {
        Hashtable sortablehash = (Hashtable)sortMethods.get( sortable );
        if ( sortablehash == null ) {
            return null;
        }
        return (TreeIterComparison)sortablehash.get( new Integer( column ) );
    }

    /**
     * Retrieve the runtime type used by the GLib library.
     */
    public static Type getType() {
        return new Type( gtk_tree_sortable_get_type() );
    }

    native static final public void gtk_tree_sortable_set_sort_column_id( Handle treeSortable, int column_id, int order );
    native static final public int gtk_tree_sortable_get_sort_column_id( Handle treeSortable );
    native static final public int gtk_tree_sortable_get_sort_column_order( Handle treeSortable );
    native static final public void gtk_tree_sortable_set_sort_func( Handle treeSortable, TreeSortable model, String compareFunc, int col );
    native static final private int gtk_tree_sortable_get_type();

    // Not implemented.
    //native static final public void gtk_tree_sortable_sort_column_changed( Handle treeSortable );
    //native static final public void gtk_tree_sortable_set_default_sort_func( Handle treeSortable, TreeSortable model, String compareFunc );
    //native static final public boolean gtk_tree_sortable_has_default_sort_func( Handle treeSortable );

}

==> libgtk-java-2.6.2.tar.bz2: libgtk-java-2.6.2/src/java/org/gnu/gtk/TreeSortableHelper.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import java.util.Hashtable;
import org.gnu.glib.Handle;
import org.gnu.glib.Type;

/**
 * Internal helper class for classes that implement the {@link TreeSortable} 
 * interface. Applications normally shouldn't use this class.
 */
public class TreeSortableHelper {

    private static Hashtable sortMethods = null;

    /** Private constructor so we don't instantiate this class. */
    private TreeSortableHelper() {}

    /**
     * Set the column in the list to sort on.
     */
    public static void setSortColumn( TreeSortable sortable, 
                                      DataColumn column, SortType order ) {
        gtk_tree_sortable_set_sort_column_id( sortable.getHandle(), 
                                              column.getColumn(), 
                                              order.getValue() );
    }

    /**
     * Get a DataColumn object representing the currently sorted column.  This
     * is not the same DataColumn used to create the store.  It is only of type
     * DataColumn (not DataColumnString, etc).  It can be compared with another
     * DataColumn object using the <tt>{@link DataColumn#equals}</tt> method.
     *
     * @return A DataColumn object representing the currently sorted column or
     * <tt>null</tt> if there is no column currently sorted.
     */
    public static DataColumn getSortColumn( TreeSortable sortable ) {
        int colid = gtk_tree_sortable_get_sort_column_id( sortable.getHandle() );
        if ( colid < 0 ) {
            return null;
        } else {
            DataColumn ret = new DataColumnInt();
            ret.setColumn( colid );
            return ret;
        }
    }

    /**
     * Get the current sorting order of the store.
     *
     * @return A SortType object defining the current sorting order of the 
     * store or <tt>null</tt> if there is no current sort order.
     */
    public static SortType getSortOrder( TreeSortable sortable ) {
        int stype = gtk_tree_sortable_get_sort_column_order( sortable.getHandle() );
        if ( stype == -1 ) {
            return null;
        } else {
            return SortType.intern( stype );
        }
    }

    /**
     * Set the class used to sort the list according to the values stored
     * in the given DataColumn.
     * <p>
     * "handleCompareFunc" is part of the TreeSortable interface.
     */
    public static void setSortMethod( TreeSortable sortable, 
                                      TreeIterComparison method, 
                                      DataColumn column ) {
        // sortMethods is a hashtable of hashtables.  that is, each key
        // (TreeSortable objects) refers to hashtable that contains
        // TreeIterComparison objects keyed to their column number.
        if ( sortMethods == null ) {
            sortMethods = new Hashtable();
        }
        Hashtable sortablehash = (Hashtable)sortMethods.get( sortable );
        if ( sortablehash == null ) {
            sortablehash = new Hashtable();
            sortMethods.put( sortable, sortablehash );
        }
        sortablehash.put( new Integer( column.getColumn() ), method );
        gtk_tree_sortable_set_sort_func( sortable.getHandle(), sortable,
                                         "handleCompareFunc", 
                                         column.getColumn() );
    }

    /**
     * Get the TreeIterComparison object stored for this column.  For internal
     * use only.
     */
    public static TreeIterComparison getMethod( TreeSortable sortable,
                                                int column ) {
        Hashtable sortablehash = (Hashtable)sortMethods.get( sortable );
        if ( sortablehash == null ) {
            return null;
        }
        return (TreeIterComparison)sortablehash.get( new Integer( column ) );
    }

    /**
     * Retrieve the runtime type used by the GLib library.
     */
    public static Type getType() {
        return new Type( gtk_tree_sortable_get_type() );
    }

    native static final private void gtk_tree_sortable_set_sort_column_id( Handle treeSortable, int column_id, int order );
    native static final private int gtk_tree_sortable_get_sort_column_id( Handle treeSortable );
    native static final private int gtk_tree_sortable_get_sort_column_order( Handle treeSortable );
    native static final private void gtk_tree_sortable_set_sort_func( Handle treeSortable, TreeSortable model, String compareFunc, int col );
    native static final private int gtk_tree_sortable_get_type();

    // Not implemented.
    //native static final public void gtk_tree_sortable_sort_column_changed( Handle treeSortable );
    //native static final public void gtk_tree_sortable_set_default_sort_func( Handle treeSortable, TreeSortable model, String compareFunc );
    //native static final public boolean gtk_tree_sortable_has_default_sort_func( Handle treeSortable );

}
